pub struct CodecRegistry;Expand description
Registry that handles decoding and encoding images.
Implementations
Sourceimpl CodecRegistry
impl CodecRegistry
Sourcepub fn decode(path: &Path) -> Result<DynamicImage>
pub fn decode(path: &Path) -> Result<DynamicImage>
Decode an image from a file path with default options.
Sourcepub fn decode_with_options(
path: &Path,
options: &DecodeOptions,
) -> Result<DynamicImage>
pub fn decode_with_options( path: &Path, options: &DecodeOptions, ) -> Result<DynamicImage>
Decode an image from a file path with custom options.
Sourcepub fn encode(
img: &DynamicImage,
path: &Path,
options: &EncodeOptions,
) -> Result<()>
pub fn encode( img: &DynamicImage, path: &Path, options: &EncodeOptions, ) -> Result<()>
Encode an image and write to a file path.